@@ -2,7 +2,7 @@ import logging
 from ..abstract import ErdReadOnlyConverter
 from ..primitives import *
 
-from gehomesdk.erd.values.laundry import ErdSmartDispense, ErdSmartDispenseSetting
+from gehomesdk.erd.values.laundry import ErdSmartDispense
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -15,8 +15,10 @@ class SmartDispenseConverter(ErdReadOnlyConverter[ErdSmartDispense]):
             # break the string into two character segments
             values = [value[i:i + 2] for i in range(0, len(value), 2)]
             int_values = list(map(erd_decode_int, values))
+            # first 2 bytes is loads remaining
+            # second 2 bytes appear to increment
             return ErdSmartDispense(
-                setting = ErdSmartDispenseSetting(int_values[0]),
+                loads_left = int_values[0],
                 raw_value=value
             )
         except Exception as ex: 
