@@ -6,4 +6,6 @@ from .fridge import *
 from .oven import *
 from .laundry import *
 from .advantium import *
-from .water_filter import *
\ No newline at end of file
+from .water_filter import *
+from .ac import *
+from .hood import *
\ No newline at end of file
